@@ -1,7 +1,7 @@
 // qsamplerOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2020, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007, Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -226,7 +226,7 @@ void OptionsForm::setup ( Options *pOptions )
 		|| !font.fromString(m_pOptions->sMessagesFont))
 		font = QFont("Monospace", 8);
 	pal = m_ui.MessagesFontTextLabel->palette();
-	pal.setColor(QPalette::Background, pal.base().color());
+	pal.setColor(QPalette::Window, pal.base().color());
 	m_ui.MessagesFontTextLabel->setPalette(pal);
 	m_ui.MessagesFontTextLabel->setFont(font);
 	m_ui.MessagesFontTextLabel->setText(font.family()
@@ -345,49 +345,19 @@ void OptionsForm::accept (void)
 		m_pOptions->iMaxRecentFiles  = m_ui.MaxRecentFilesSpinBox->value();
 		m_pOptions->iBaseFontSize  = m_ui.BaseFontSizeComboBox->currentText().toInt();
 		// Custom color/style theme options...
-		const QString sOldCustomStyleTheme = m_pOptions->sCustomStyleTheme;
 		if (m_ui.CustomStyleThemeComboBox->currentIndex() > 0)
 			m_pOptions->sCustomStyleTheme = m_ui.CustomStyleThemeComboBox->currentText();
 		else
 			m_pOptions->sCustomStyleTheme.clear();
-		const QString sOldCustomColorTheme = m_pOptions->sCustomColorTheme;
 		if (m_ui.CustomColorThemeComboBox->currentIndex() > 0)
 			m_pOptions->sCustomColorTheme = m_ui.CustomColorThemeComboBox->currentText();
 		else
 			m_pOptions->sCustomColorTheme.clear();
-		// Check whether restart is needed or whether
-		// custom options maybe set up immediately...
-		int iNeedRestart = 0;
-		if (m_pOptions->sCustomStyleTheme != sOldCustomStyleTheme) {
-			if (m_pOptions->sCustomStyleTheme.isEmpty()) {
-				++iNeedRestart;
-			} else {
-				QApplication::setStyle(
-					QStyleFactory::create(m_pOptions->sCustomStyleTheme));
-			}
-		}
-		if (m_pOptions->sCustomColorTheme != sOldCustomColorTheme) {
-			if (m_pOptions->sCustomColorTheme.isEmpty()) {
-				++iNeedRestart;
-			} else {
-				QPalette pal;
-				if (PaletteForm::namedPalette(
-						&m_pOptions->settings(), m_pOptions->sCustomColorTheme, pal))
-					QApplication::setPalette(pal);
-			}
-		}
-		// Show restart message if needed...
-		if (iNeedRestart > 0) {
-			QMessageBox::information(this,
-				tr("Information"),
-				tr("Some settings may be only effective\n"
-				"next time you start this application."));
-		}
 		// Reset dirty flag.
 		m_iDirtyCount = 0;
 	}
 
-	// if the user modified the limits, apply them to the sampler
+	// If the user modified the limits, apply them to the sampler
 	// (and store it later in qsampler's configuration)
 	if (bMaxVoicesModified && m_ui.MaxVoicesSpinBox->isEnabled())
 		m_pOptions->setMaxVoices(m_ui.MaxVoicesSpinBox->value());
@@ -528,12 +498,12 @@ void OptionsForm::chooseMessagesFont (void)
 void OptionsForm::toggleDisplayEffect ( bool bOn )
 {
 	QPalette pal;
-	pal.setColor(QPalette::Foreground, Qt::green);
+	pal.setColor(QPalette::WindowText, Qt::green);
 	if (bOn) {
 		QPixmap pm(":/images/displaybg1.png");
-		pal.setBrush(QPalette::Background, QBrush(pm));
+		pal.setBrush(QPalette::Window, QBrush(pm));
 	} else {
-		pal.setColor(QPalette::Background, Qt::black);
+		pal.setColor(QPalette::Window, Qt::black);
 	}
 	m_ui.DisplayFontTextLabel->setPalette(pal);
 
